@@ -16,83 +16,89 @@
 #'
 #' @examples
 #' # survival analysis
+#' if (requireNamespace("survival", quietly = TRUE) &&
+#' requireNamespace("glmnet", quietly = TRUE) &&
+#' requireNamespace("splitTools", quietly = TRUE)) {
 #'
-#' dataset <- survival::colon |>
-#'   data.table::as.data.table() |>
-#'   na.omit()
-#' dataset <- dataset[get("etype") == 2, ]
+#'   dataset <- survival::colon |>
+#'     data.table::as.data.table() |>
+#'     na.omit()
+#'   dataset <- dataset[get("etype") == 2, ]
 #'
-#' seed <- 123
-#' surv_cols <- c("status", "time", "rx")
+#'   seed <- 123
+#'   surv_cols <- c("status", "time", "rx")
 #'
-#' feature_cols <- colnames(dataset)[3:(ncol(dataset) - 1)]
+#'   feature_cols <- colnames(dataset)[3:(ncol(dataset) - 1)]
 #'
-#' param_list_glmnet <- expand.grid(
-#'   alpha = seq(0, 1, .2)
-#' )
+#'   param_list_glmnet <- expand.grid(
+#'     alpha = seq(0, 1, .2)
+#'   )
 #'
-#' ncores <- 2L
+#'   ncores <- 2L
 #'
-#' split_vector <- splitTools::multi_strata(
-#'   df = dataset[, .SD, .SDcols = surv_cols],
-#'   strategy = "kmeans",
-#'   k = 4
-#' )
+#'   split_vector <- splitTools::multi_strata(
+#'     df = dataset[, .SD, .SDcols = surv_cols],
+#'     strategy = "kmeans",
+#'     k = 4
+#'   )
 #'
-#' train_x <- model.matrix(
-#'   ~ -1 + .,
-#'   dataset[, .SD, .SDcols = setdiff(feature_cols, surv_cols[1:2])]
-#' )
-#' train_y <- survival::Surv(
-#'   event = (dataset[, get("status")] |>
-#'              as.character() |>
-#'              as.integer()),
-#'   time = dataset[, get("time")],
-#'   type = "right"
-#' )
+#'   train_x <- model.matrix(
+#'     ~ -1 + .,
+#'     dataset[, .SD, .SDcols = setdiff(feature_cols, surv_cols[1:2])]
+#'   )
+#'   train_y <- survival::Surv(
+#'     event = (dataset[, get("status")] |>
+#'                as.character() |>
+#'                as.integer()),
+#'     time = dataset[, get("time")],
+#'     type = "right"
+#'   )
 #'
 #'
-#' fold_list <- splitTools::create_folds(
-#'   y = split_vector,
-#'   k = 3,
-#'   type = "stratified",
-#'   seed = seed
-#' )
+#'   fold_list <- splitTools::create_folds(
+#'     y = split_vector,
+#'     k = 3,
+#'     type = "stratified",
+#'     seed = seed
+#'   )
 #'
-#' surv_glmnet_cox_optimizer <- mlexperiments::MLCrossValidation$new(
-#'   learner = LearnerSurvGlmnetCox$new(),
-#'   fold_list = fold_list,
-#'   ncores = ncores,
-#'   seed = seed
-#' )
-#' surv_glmnet_cox_optimizer$learner_args <- list(
-#'   alpha = 0.8,
-#'   lambda = 0.002
-#' )
-#' surv_glmnet_cox_optimizer$performance_metric <- c_index
+#'   surv_glmnet_cox_optimizer <- mlexperiments::MLCrossValidation$new(
+#'     learner = LearnerSurvGlmnetCox$new(),
+#'     fold_list = fold_list,
+#'     ncores = ncores,
+#'     seed = seed
+#'   )
+#'   surv_glmnet_cox_optimizer$learner_args <- list(
+#'     alpha = 0.8,
+#'     lambda = 0.002
+#'   )
+#'   surv_glmnet_cox_optimizer$performance_metric <- c_index
 #'
-#' # set data
-#' surv_glmnet_cox_optimizer$set_data(
-#'   x = train_x,
-#'   y = train_y
-#' )
+#'   # set data
+#'   surv_glmnet_cox_optimizer$set_data(
+#'     x = train_x,
+#'     y = train_y
+#'   )
+#'
+#'   surv_glmnet_cox_optimizer$execute()
+#' }
 #'
-#' surv_glmnet_cox_optimizer$execute()
-
 #' @export
 #'
-LearnerSurvGlmnetCox <- R6::R6Class( # nolint
+LearnerSurvGlmnetCox <- R6::R6Class(
+  # nolint
   classname = "LearnerSurvGlmnetCox",
   inherit = mlexperiments::MLLearnerBase,
   public = list(
-
     #' @description
     #' Create a new `LearnerSurvGlmnetCox` object.
     #'
     #' @return A new `LearnerSurvGlmnetCox` R6 object.
     #'
     #' @examples
-    #' LearnerSurvGlmnetCox$new()
+    #' if (requireNamespace("glmnet", quietly = TRUE)) {
+    #'   LearnerSurvGlmnetCox$new()
+    #' }
     #'
     initialize = function() {
       if (!requireNamespace("glmnet", quietly = TRUE)) {
@@ -120,12 +126,13 @@ surv_glmnet_cox_ce <- function() {
   c("surv_glmnet_cox_optimization", "surv_glmnet_cox_fit")
 }
 
-surv_glmnet_cox_bsF <- function(...) { # nolint
+surv_glmnet_cox_bsF <- function(...) {
+  # nolint
   kwargs <- list(...)
   # call to surv_glmnet_cox_optimization here with ncores = 1, since the
   # Bayesian search is parallelized already / "FUN is fitted n times
   # in m threads"
-  set.seed(seed)#, kind = "L'Ecuyer-CMRG")
+  set.seed(seed) #, kind = "L'Ecuyer-CMRG")
   bayes_opt_glmnet <- surv_glmnet_cox_optimization(
     x = x,
     y = y,
@@ -145,13 +152,13 @@ surv_glmnet_cox_bsF <- function(...) { # nolint
 
 # tune lambda
 surv_glmnet_cox_optimization <- function(
-    x,
-    y,
-    params,
-    fold_list,
-    ncores,
-    seed
-  ) {
+  x,
+  y,
+  params,
+  fold_list,
+  ncores,
+  seed
+) {
   stopifnot(
     inherits(x = y, what = "Surv"),
     is.list(params),
@@ -215,15 +222,17 @@ surv_glmnet_cox_optimization <- function(
 
 surv_glmnet_cox_fit <- function(x, y, ncores, seed, ...) {
   kwargs <- list(...)
-  stopifnot(!sapply(
-    X = c("x", "y", "family", "standardize"),
-    FUN = function(x) {
-      x %in% names(kwargs)
-    }
-  ))
+  stopifnot(
+    !sapply(
+      X = c("x", "y", "family", "standardize"),
+      FUN = function(x) {
+        x %in% names(kwargs)
+      }
+    )
+  )
   kwargs <- kdry::list.append(
     kwargs,
-      list(
+    list(
       family = "cox",
       standardize = TRUE
     )
