@@ -58,8 +58,8 @@ fold_list <- splitTools::create_folds(
 )
 
 options("mlexperiments.bayesian.max_init" = 10L)
-options("mlexperiments.optim.xgb.nrounds" = 100L)
-options("mlexperiments.optim.xgb.early_stopping_rounds" = 10L)
+options("mlexperiments.optim.xgb.nrounds" = 20L)
+options("mlexperiments.optim.xgb.early_stopping_rounds" = 5L)
 # ###########################################################################
 # %% TUNING
 # ###########################################################################
@@ -78,7 +78,7 @@ xgboost_bounds <- list(
 )
 
 optim_args <- list(
-  iters.n = ncores,
+  n_iter = ncores,
   kappa = 3.5,
   acq = "ucb"
 )
@@ -88,6 +88,10 @@ optim_args <- list(
 # ###########################################################################
 
 test_that(desc = "test nested cv, bayesian - surv_xgboost_aft", code = {
+  testthat::skip_if_not_installed("rBayesianOptimizaion")
+  testthat::skip_if_not_installed("xgboost")
+  testthat::skip_if_not_installed("glmnet")
+
   surv_xgboost_aft_optimizer <- mlexperiments::MLNestedCV$new(
     learner = LearnerSurvXgboostAft$new(
       metric_optimization_higher_better = FALSE
@@ -134,6 +138,9 @@ learner_args <- list(
 )
 
 test_that(desc = "test nested cv, grid - surv_xgboost_aft", code = {
+  testthat::skip_if_not_installed("xgboost")
+  testthat::skip_if_not_installed("glmnet")
+
   surv_xgboost_aft_optimizer <- mlexperiments::MLNestedCV$new(
     learner = LearnerSurvXgboostAft$new(
       metric_optimization_higher_better = FALSE
